(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     53573,       1501]*)
(*NotebookOutlinePosition[     54224,       1524]*)
(*  CellTagsIndexPosition[     54180,       1520]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(\(\n (*\ various\ parameters, \ all\ in\ SI\ units\ *) \n
    phi0\  = \ 0.6; \  (*\ Prefactor\ of\ polymer\ volume\ fraction*) \ \n
    zi = 10^\(-6\); \  (*Point\ of\ inflection\ *) \nw\  = 10^\(-7\); \ 
     (*\ Width\ of\ fuzzy\ interface\ *) \nGinf\  = \ 10^7; \ 
     (*\ Prefactor\ of\ shear\ modulus\ *) \nrho = 10^3; \ \ 
     (*Density\ chosen\ as\ constant*) \netaliq\  = \ 10^\(-3\); \ 
     (*Viscosity\ of\ the\ liquid\ *) \nom\  = \ 2\ Pi\ 5\ 10^6; \ 
     (*Radial\ frequency\ *) \nZq\  = \ 8.8\ 10^6; \ 
     (*Acoustic\ impedance\ of\ AT - cut\ quartz*) \nf0\  = \ 5\ 10^6; \ 
     (*Frequency\ of\ fundamental*) \nzmax = 2\ 10^\(-6\); \ 
     (*Upper\ limit\ of\ integration\ range*) \n
     (*\ Polymer\ volume\ fraction\ *) \ \n
    phi = phi0\ 1/2 \((1 - Tanh[\((z - zi)\)/w])\); \n\n
     (*Dependence\ of\ relaxation\ time\ on\ phi\ *) \n
    tau = 10^\(-10\)\ Power[10, 3  phi/phi0]; \n
     (*\ Shear\ modulus\ according\ to\ Maxwell\ model, \ added\ onto\n
      \t\ \ the\ shear\ modulus\ of\ the\ bulk\ liquid\ *) \ \n
    G = Ginf\ I\ om\ tau/\((1 + I\ om\ tau)\)\  + \ I\ om\ etaliq; \n\n
     (*\ Display\ G' \((z)\)\ and\ \(G'\)' \((z)\)\ *) \nPrint["\<Re[G]\>"]; 
    Plot[Re[G], {z, 0, zmax}]; \nPrint["\<Im[G]\>"]; 
    Plot[Im[G], {z, 0, zmax}]; \n
     (*\ The\ above\ two\ lines\ do\ not\ run\ on\ the\ version\ available\ on
        \ www.mathics.net*) \n
     (*\ The\ rest\ of\ the\ program\ should\ run*) \n\n
     (*Below\ come\ the\ essential\ steps*) \nG2\  = \ G /. z -> zmax - z; \ 
     (*revert\ z - scale, \ 
      so\ that\ Mathematica\ can\ integrate\ forward\ *) \n
    WaveEquation\  = \ D[G2\ D[u[z], z], z] == \(-rho\)\ om^2\ u[z]; \n
    solution = 
      NDSolve[{WaveEquation, u[0] == 1, \(u'\)[0] == 1}, u, {z, 0, zmax}]; \n
    displacement = \(u[z] /. solution[\([1]\)]\) /. z -> zmax - z; \ \ 
     (*Again\ revert\ z*) \nvelocity = I\ om\ displacement /. z -> 0; \n
    stress = \(-G\)\ D[displacement, z] /. z -> 0\ ; \ \n\ \ \ 
     (*The\ minus\ sign\ occurs\ because\ the\ stress\ in\ the\ SLA\ acts\ 
          into\ the\  + z\ direction*) \n
    Df = f0\ I\ /\((Pi\ Zq)\) stress/velocity\ \ \ \ \ \ 
     (*\ The\ frequency\ shift\ according\ to\ the\ SLA*) \)\)], "Input"],

Cell[BoxData[
    \("Re[G]"\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 476190 0.0147151 6.48242e-008 [
[.2619 .00222 -16.5 -12.5 ]
[.2619 .00222 16.5 0 ]
[.5 .00222 -16.5 -12.5 ]
[.5 .00222 16.5 0 ]
[.7381 .00222 -22.5 -12.5 ]
[.7381 .00222 22.5 0 ]
[.97619 .00222 -16.5 -12.5 ]
[.97619 .00222 16.5 0 ]
[.01131 .14436 -28.5 -6.25 ]
[.01131 .14436 0 6.25 ]
[.01131 .27401 -28.5 -6.25 ]
[.01131 .27401 0 6.25 ]
[.01131 .40366 -28.5 -6.25 ]
[.01131 .40366 0 6.25 ]
[.01131 .53331 -28.5 -6.25 ]
[.01131 .53331 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .01472 m
.2619 .02097 L
s
gsave
.2619 .00222 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.5 .01472 m
.5 .02097 L
s
gsave
.5 .00222 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.7381 .01472 m
.7381 .02097 L
s
gsave
.7381 .00222 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .14436 m
.03006 .14436 L
s
gsave
.01131 .14436 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.02381 .27401 m
.03006 .27401 L
s
gsave
.01131 .27401 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.02381 .40366 m
.03006 .40366 L
s
gsave
.01131 .40366 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(6) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.02381 .53331 m
.03006 .53331 L
s
gsave
.01131 .53331 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(8) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.02381 .04713 m
.02756 .04713 L
s
.02381 .07954 m
.02756 .07954 L
s
.02381 .11195 m
.02756 .11195 L
s
.02381 .17678 m
.02756 .17678 L
s
.02381 .20919 m
.02756 .20919 L
s
.02381 .2416 m
.02756 .2416 L
s
.02381 .30642 m
.02756 .30642 L
s
.02381 .33884 m
.02756 .33884 L
s
.02381 .37125 m
.02756 .37125 L
s
.02381 .43607 m
.02756 .43607 L
s
.02381 .46848 m
.02756 .46848 L
s
.02381 .5009 m
.02756 .5009 L
s
.02381 .56572 m
.02756 .56572 L
s
.02381 .59813 m
.02756 .59813 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02846 .60332 L
.03279 .60332 L
.03793 .60332 L
.04262 .60332 L
.0522 .60332 L
.05746 .60332 L
.06244 .60332 L
.06754 .60332 L
.07295 .60332 L
.08265 .60332 L
.08804 .60332 L
.09308 .60332 L
.09862 .60332 L
.10458 .60332 L
.11468 .60332 L
.1204 .60332 L
.12571 .60332 L
.13544 .60332 L
.14087 .60332 L
.1458 .60332 L
.15068 .60332 L
.15583 .60332 L
.16505 .60332 L
.17018 .60332 L
.17498 .60332 L
.18019 .60332 L
.18587 .60332 L
.1913 .60332 L
.19632 .60332 L
.20103 .60332 L
.20622 .60332 L
.21522 .60331 L
.22015 .60331 L
.22478 .60331 L
.23461 .60331 L
.23955 .60331 L
.24496 .6033 L
.2496 .6033 L
.25455 .60329 L
.26347 .60328 L
.2688 .60327 L
.27371 .60326 L
.279 .60325 L
.28481 .60323 L
.2946 .60318 L
.29996 .60315 L
.30496 .60311 L
.30994 .60306 L
.31537 .603 L
Mistroke
.32016 .60293 L
.32525 .60283 L
.3303 .60272 L
.33487 .60259 L
.34379 .60225 L
.34868 .60201 L
.35384 .60169 L
.36307 .6009 L
.36822 .60031 L
.37301 .59963 L
.37827 .59869 L
.38391 .59741 L
.38921 .59587 L
.39411 .59408 L
.39948 .59158 L
.40519 .58814 L
.41013 .58428 L
.41476 .57969 L
.41985 .57323 L
.42532 .56404 L
.43029 .55293 L
.43492 .53943 L
.43999 .51984 L
.4454 .4915 L
.4511 .45062 L
.45647 .3992 L
.46651 .27031 L
.47626 .13949 L
.48117 .09058 L
.48396 .06985 L
.48657 .05479 L
.48896 .04418 L
.49122 .03649 L
.49326 .03119 L
.49547 .0268 L
.49788 .0233 L
.50044 .02067 L
.50262 .01906 L
.50503 .01779 L
.50737 .01692 L
.5087 .01655 L
.50994 .01626 L
.51244 .01581 L
.51384 .01562 L
.51511 .01548 L
.51739 .01529 L
.51986 .01513 L
.5222 .01503 L
.52435 .01496 L
.52684 .0149 L
Mistroke
.52917 .01486 L
.53173 .01483 L
.53448 .0148 L
.53735 .01478 L
.54008 .01477 L
.54253 .01476 L
.5452 .01475 L
.54776 .01475 L
.55052 .01474 L
.55296 .01474 L
.55553 .01474 L
.55785 .01473 L
.56041 .01473 L
.56489 .01473 L
.57013 .01473 L
.57306 .01473 L
.57574 .01473 L
.58094 .01473 L
.58587 .01472 L
.59046 .01472 L
.59553 .01472 L
.60082 .01472 L
.60579 .01472 L
.61466 .01472 L
.61965 .01472 L
.62422 .01472 L
.62896 .01472 L
.63403 .01472 L
.64315 .01472 L
.64874 .01472 L
.65401 .01472 L
.6587 .01472 L
.66386 .01472 L
.67359 .01472 L
.67891 .01472 L
.68389 .01472 L
.69279 .01472 L
.69779 .01472 L
.70235 .01472 L
.70713 .01472 L
.71223 .01472 L
.72138 .01472 L
.727 .01472 L
.73227 .01472 L
.73698 .01472 L
.74213 .01472 L
.75193 .01472 L
.75728 .01472 L
.76226 .01472 L
.77119 .01472 L
Mistroke
.7762 .01472 L
.78075 .01472 L
.78558 .01472 L
.7907 .01472 L
.79989 .01472 L
.80499 .01472 L
.80977 .01472 L
.81498 .01472 L
.82067 .01472 L
.82605 .01472 L
.83104 .01472 L
.83621 .01472 L
.84091 .01472 L
.84987 .01472 L
.85479 .01472 L
.85943 .01472 L
.86918 .01472 L
.8741 .01472 L
.8795 .01472 L
.8841 .01472 L
.88905 .01472 L
.89797 .01472 L
.90325 .01472 L
.90813 .01472 L
.91339 .01472 L
.9192 .01472 L
.92895 .01472 L
.9343 .01472 L
.93931 .01472 L
.94868 .01472 L
.95339 .01472 L
.95855 .01472 L
.96297 .01472 L
.96769 .01472 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00C03oool01@000000oooo0?ooo`3oool0000000<0
oooo1P0000020?ooo`030000003oool0oooo02L0oooo1@0000000`3oool000000?ooo`020?ooo`H0
00000P3oool00`000000oooo0?ooo`0Q0?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool600000080oooo00<000000?ooo`3oool0903oool30000
0080oooo00@000000?ooo`3oool0oooo1P0000020?ooo`030000003oool0oooo00d0oooo001;0?oo
o`030000003oool0000000<0oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool0
00000?ooo`000000:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00L0
00000?ooo`3oool0oooo0000003oool0000002@0oooo00<000000?ooo`3oool01P3oool00`000000
oooo000000030?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0
000002D0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`070000003oool0
oooo0?ooo`000000oooo0000000>0?ooo`00C@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000002X0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo0000000T
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02
0?ooo`070000003oool0oooo0?ooo`000000oooo0000000V0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000003P3oool004/0
oooo0P0000040?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0
000002X0oooo00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`070000003oool0
oooo0?ooo`000000oooo0000000T0?ooo`030000003oool0oooo00H0oooo0P0000040?ooo`030000
003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000002H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo0000
000>0?ooo`00B`3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01`000000oooo0?ooo`3oool000000?ooo`000000:P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0000000T0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00L0
00000?ooo`3oool0oooo0000003oool0000002D0oooo00<000000?ooo`0000000P3oool01@000000
oooo0?ooo`3oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000h0oooo001;
0?ooo`<00000203oool2000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0N
0?ooo`8000002@3oool2000000@0oooo00<000000?ooo`3oool01P3oool3000001T0oooo0P000008
0?ooo`<00000203oool2000000@0oooo00<000000?ooo`3oool01P3oool3000001`0oooo00<00000
0?ooo`3oool01`3oool2000000@0oooo00<000000?ooo`3oool01P3oool3000000@0oooo001V0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`000000?@3oool00`000000oooo0000000e0?oo
o`030000003oool0000000@0oooo001P0?ooo`<00000103oool00`000000oooo0?ooo`0b0?ooo`<0
00000P3oool3000003P0oooo0`0000020?ooo`<00000<03oool300000080oooo0`0000040?ooo`00
7`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00@0oooo000O0?ooo`030000003o
ool0oooo04<0oooo0`00000j0?ooo`800000?P3oool2000003H0oooo0P0000040?ooo`007`3oool0
0`000000oooo0?ooo`3n0?ooo`007`3oool00`000000oooo0?ooo`3n0?ooo`006@3ooool000000/0
oooo000O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00T0oooo0`0000090?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo
000O0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0>03oool2000003X0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`0?0?ooo`007`3oool00`000000oooo0?ooo`1c
0?ooo`030000003oool0oooo08P0oooo000O0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool0R03oool001l0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`290?ooo`00
7`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo08T0oooo000O0?ooo`030000003o
ool0oooo0780oooo00<000000?ooo`3oool0R@3oool001l0oooo0P00001c0?ooo`030000003oool0
oooo08T0oooo000O0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0RP3oool001l0
oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`2:0?ooo`007`3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo08X0oooo000O0?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0RP3oool001l0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`2:
0?ooo`007`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo08X0oooo000O0?ooo`03
0000003oool0oooo0740oooo00<000000?ooo`3oool0RP3oool001l0oooo0P00001b0?ooo`030000
003oool0oooo08X0oooo000O0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0R`3o
ool001l0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`2;0?ooo`007`3oool00`00
0000oooo0?ooo`1`0?ooo`030000003oool0oooo08/0oooo000O0?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0R`3oool001l0oooo00<000000?ooo`3oool0L03oool00`000000oooo
0?ooo`2;0?ooo`007`3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo08/0oooo000O
0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0R`3oool001l0oooo00<000000?oo
o`3oool0L03oool00`000000oooo0?ooo`2;0?ooo`007`3oool200000700oooo00<000000?ooo`3o
ool0S03oool001l0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`2<0?ooo`007`3o
ool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo08`0oooo000O0?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool0S03oool000040?ooo`000000000000000080oooo00@00000
0?ooo`3oool0oooo1P0000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0K`3o
ool00`000000oooo0?ooo`2<0?ooo`0000<0oooo0000003oool0103oool00`000000oooo00000003
0?ooo`070000003oool0oooo0?ooo`000000oooo0000000;0?ooo`030000003oool0oooo06l0oooo
00<000000?ooo`3oool0S03oool00080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`020?ooo`070000003oool0oooo0?ooo`000000oooo0000000;0?ooo`030000003oool0oooo06l0
oooo00<000000?ooo`3oool0S03oool00080oooo00<000000?ooo`3oool00P3oool00`000000oooo
000000030?ooo`070000003oool0oooo0?ooo`000000oooo0000000;0?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool0S03oool000040?ooo`000000oooo00000080oooo00D000000?oo
o`3oool0oooo000000020?ooo`070000003oool0oooo0?ooo`000000oooo0000000;0?ooo`<00000
K`3oool00`000000oooo0?ooo`2<0?ooo`000P3oool00`000000oooo0?ooo`070?ooo`800000103o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0S03o
ool001H0oooo0`0000060?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0S03oool0
01H0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
08`0oooo000F0?ooo`<000001P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo08d0
oooo000F0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0KP3oool00`000000oooo
0?ooo`2=0?ooo`005`3oool2000000H0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?oo
o`2=0?ooo`007`3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo08d0oooo000O0?oo
o`800000K`3oool00`000000oooo0?ooo`2=0?ooo`007`3oool00`000000oooo0?ooo`1^0?ooo`03
0000003oool0oooo08d0oooo000O0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0
S@3oool001l0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`2=0?ooo`007`3oool0
0`000000oooo0?ooo`1^0?ooo`030000003oool0oooo08d0oooo000O0?ooo`030000003oool0oooo
06h0oooo00<000000?ooo`3oool0S@3oool001l0oooo00<000000?ooo`3oool0KP3oool00`000000
oooo0?ooo`2=0?ooo`007`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo08h0oooo
000O0?ooo`800000KP3oool00`000000oooo0?ooo`2>0?ooo`007`3oool00`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo08h0oooo000O0?ooo`030000003oool0oooo06d0oooo00<000000?oo
o`3oool0SP3oool001l0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`2>0?ooo`00
7`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo08h0oooo000O0?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool0SP3oool001l0oooo00<000000?ooo`3oool0K@3oool0
0`000000oooo0?ooo`2>0?ooo`007`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
08h0oooo000O0?ooo`800000KP3oool00`000000oooo0?ooo`2>0?ooo`007`3oool00`000000oooo
0?ooo`1]0?ooo`030000003oool0oooo08h0oooo000O0?ooo`030000003oool0oooo06`0oooo00<0
00000?ooo`3oool0S`3oool001l0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`2?
0?ooo`007`3oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo08l0oooo00020?ooo`<0
000000<0oooo0000003oool00P3oool600000080oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`1/0?ooo`030000003oool0oooo08l0oooo00030?ooo`070000003oool0oooo0?ooo`00
0000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo0000000;0?ooo`030000003o
ool0oooo06`0oooo00<000000?ooo`3oool0S`3oool000030?ooo`0000000000008000000`3oool0
0`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo0000000;0?ooo`030000
003oool0oooo06`0oooo00<000000?ooo`3oool0S`3oool000040?ooo`000000oooo000000<0oooo
00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`0000002`3oool30000
06`0oooo00<000000?ooo`3oool0S`3oool00080oooo0P0000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000002`3oool00`000000oooo0?oo
o`1/0?ooo`030000003oool0oooo08l0oooo00030?ooo`030000003oool0oooo00H0oooo0P000004
0?ooo`040000003oool0oooo0?ooo`<000001P3oool00`000000oooo0?ooo`1/0?ooo`030000003o
ool0oooo08l0oooo000F0?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool0K03oool0
0`000000oooo0?ooo`2?0?ooo`005P3oool3000000H0oooo00<000000?ooo`3oool0K03oool00`00
0000oooo0?ooo`2?0?ooo`005P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo06`0
oooo00<000000?ooo`3oool0S`3oool001L0oooo0P0000060?ooo`030000003oool0oooo06`0oooo
00<000000?ooo`3oool0S`3oool001l0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?oo
o`2?0?ooo`007`3oool2000006`0oooo00<000000?ooo`3oool0T03oool001l0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`2@0?ooo`007`3oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo0900oooo000O0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0
T03oool001l0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`2@0?ooo`007`3oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0900oooo000O0?ooo`030000003oool0oooo
06/0oooo00<000000?ooo`3oool0T03oool001l0oooo00<000000?ooo`3oool0J`3oool00`000000
oooo0?ooo`2@0?ooo`007`3oool2000006`0oooo00<000000?ooo`3oool0T03oool001l0oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo0?ooo`2@0?ooo`007`3oool00`000000oooo0?ooo`1[
0?ooo`030000003oool0oooo0900oooo000O0?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0T03oool001l0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`2@0?ooo`00
7`3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0900oooo000O0?ooo`030000003o
ool0oooo06/0oooo00<000000?ooo`3oool0T03oool001l0oooo00<000000?ooo`3oool0J`3oool0
0`000000oooo0?ooo`2@0?ooo`007`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo
0940oooo000O0?ooo`800000J`3oool00`000000oooo0?ooo`2A0?ooo`007`3oool00`000000oooo
0?ooo`1Z0?ooo`030000003oool0oooo0940oooo000O0?ooo`030000003oool0oooo06X0oooo00<0
00000?ooo`3oool0T@3oool001l0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`2A
0?ooo`0000<0oooo0000000000000`3oool010000000oooo0?ooo`3oool600000080oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0940oooo0000103o
ool000000?ooo`0000030?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000
003oool0000000/0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`2A0?ooo`0000@0
oooo0000003oool00000103oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`00
0000oooo0000000;0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0T@3oool00003
0?ooo`000000000000@0oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000002`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0940oooo00000`3o
ool000000?ooo`030?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo0?ooo`3o
ool000000?ooo`0000002`3oool3000006X0oooo00<000000?ooo`3oool0T@3oool00080oooo0P00
00080?ooo`800000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06X0oooo00<0
00000?ooo`3oool0T@3oool001H0oooo0`0000060?ooo`030000003oool0oooo06X0oooo00<00000
0?ooo`3oool0T@3oool001H0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`1Y0?oo
o`030000003oool0oooo0980oooo000F0?ooo`<000001P3oool00`000000oooo0?ooo`1Y0?ooo`03
0000003oool0oooo0980oooo000F0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
J@3oool00`000000oooo0?ooo`2B0?ooo`005`3oool2000000H0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`2B0?ooo`007`3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0
oooo0980oooo000O0?ooo`800000JP3oool00`000000oooo0?ooo`2B0?ooo`007`3oool00`000000
oooo0?ooo`1X0?ooo`030000003oool0oooo09<0oooo000O0?ooo`030000003oool0oooo06P0oooo
00<000000?ooo`3oool0T`3oool001l0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?oo
o`2C0?ooo`007`3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo09<0oooo000O0?oo
o`030000003oool0oooo06P0oooo00<000000?ooo`3oool0T`3oool001l0oooo00<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`2C0?ooo`007`3oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo09<0oooo000O0?ooo`800000J@3oool00`000000oooo0?ooo`2C0?ooo`007`3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo09@0oooo000O0?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool0U03oool001l0oooo00<000000?ooo`3oool0I`3oool00`000000
oooo0?ooo`2D0?ooo`007`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo09@0oooo
000O0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0U03oool001l0oooo00<00000
0?ooo`3oool0I`3oool00`000000oooo0?ooo`2D0?ooo`007`3oool00`000000oooo0?ooo`1W0?oo
o`030000003oool0oooo09@0oooo000O0?ooo`800000J03oool00`000000oooo0?ooo`2D0?ooo`00
7`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo09@0oooo000O0?ooo`030000003o
ool0oooo06H0oooo00<000000?ooo`3oool0U@3oool001l0oooo00<000000?ooo`3oool0IP3oool0
0`000000oooo0?ooo`2E0?ooo`007`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo
09D0oooo00020?ooo`050000003oool0oooo0?ooo`0000000`3oool600000080oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo09D0oooo0000103oool0
00000?ooo`0000030?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003o
ool0000000/0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`2E0?ooo`0000@0oooo
0000003oool00000103oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000
oooo0000000;0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0UP3oool00080oooo
00<000000?ooo`3oool00P3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`00
0000oooo0000000;0?ooo`<00000I@3oool00`000000oooo0?ooo`2F0?ooo`0000@0oooo0000003o
ool000000P3oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`3oool0oooo0000
003oool0000000/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`2G0?ooo`000P3o
ool00`000000oooo0?ooo`070?ooo`800000103oool010000000oooo0?ooo`3oool3000000H0oooo
00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`2G0?ooo`005P3oool00`000000oooo0000
00060?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0U`3oool001H0oooo0`000006
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0V03oool001H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo09P0oooo000G0?ooo`80
00001P3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo09P0oooo000O0?ooo`030000
003oool0oooo0680oooo00<000000?ooo`3oool0V@3oool001l0oooo0P00001S0?ooo`030000003o
ool0oooo09T0oooo000O0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0VP3oool0
01l0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`2K0?ooo`007`3oool00`000000
oooo0?ooo`1O0?ooo`030000003oool0oooo09`0oooo000O0?ooo`030000003oool0oooo05l0oooo
00<000000?ooo`3oool0W03oool001l0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`2M0?ooo`007`3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo09h0oooo000O0?oo
o`030000003oool0oooo05X0oooo0`00002Q0?ooo`007`3oool00`000000oooo0?ooo`1G0?ooo`<0
0000Y03oool001l0oooo0P00001@0?ooo`P00000Y`3oool001l0ooooDP00002_0?ooo`007`3oool0
0`000000oooo0?ooo`3n0?ooo`007`3oool00`000000oooo0?ooo`3n0?ooo`007`3oool00`000000
oooo0?ooo`3n0?ooo`007`3oool00`000000oooo0?ooo`3n0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.6489*^-07, -1.26878*^06, 
  8.37302*^-09, 61507.1}}],

Cell[BoxData[
    \("Im[G]"\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 476190 0.0147151 1.16986e-007 [
[.2619 .00222 -16.5 -12.5 ]
[.2619 .00222 16.5 0 ]
[.5 .00222 -16.5 -12.5 ]
[.5 .00222 16.5 0 ]
[.7381 .00222 -22.5 -12.5 ]
[.7381 .00222 22.5 0 ]
[.97619 .00222 -16.5 -12.5 ]
[.97619 .00222 16.5 0 ]
[.01131 .1317 -28.5 -6.25 ]
[.01131 .1317 0 6.25 ]
[.01131 .24869 -28.5 -6.25 ]
[.01131 .24869 0 6.25 ]
[.01131 .36567 -28.5 -6.25 ]
[.01131 .36567 0 6.25 ]
[.01131 .48266 -28.5 -6.25 ]
[.01131 .48266 0 6.25 ]
[.01131 .59965 -28.5 -6.25 ]
[.01131 .59965 0 6.25 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .01472 m
.2619 .02097 L
s
gsave
.2619 .00222 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.5 .01472 m
.5 .02097 L
s
gsave
.5 .00222 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.7381 .01472 m
.7381 .02097 L
s
gsave
.7381 .00222 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .01472 m
.97619 .02097 L
s
gsave
.97619 .00222 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .1317 m
.03006 .1317 L
s
gsave
.01131 .1317 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.02381 .24869 m
.03006 .24869 L
s
gsave
.01131 .24869 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.02381 .36567 m
.03006 .36567 L
s
gsave
.01131 .36567 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.02381 .48266 m
.03006 .48266 L
s
gsave
.01131 .48266 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.02381 .59965 m
.03006 .59965 L
s
gsave
.01131 .59965 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.02381 .03811 m
.02756 .03811 L
s
.02381 .06151 m
.02756 .06151 L
s
.02381 .08491 m
.02756 .08491 L
s
.02381 .1083 m
.02756 .1083 L
s
.02381 .1551 m
.02756 .1551 L
s
.02381 .1785 m
.02756 .1785 L
s
.02381 .20189 m
.02756 .20189 L
s
.02381 .22529 m
.02756 .22529 L
s
.02381 .27209 m
.02756 .27209 L
s
.02381 .29548 m
.02756 .29548 L
s
.02381 .31888 m
.02756 .31888 L
s
.02381 .34228 m
.02756 .34228 L
s
.02381 .38907 m
.02756 .38907 L
s
.02381 .41247 m
.02756 .41247 L
s
.02381 .43587 m
.02756 .43587 L
s
.02381 .45926 m
.02756 .45926 L
s
.02381 .50606 m
.02756 .50606 L
s
.02381 .52946 m
.02756 .52946 L
s
.02381 .55285 m
.02756 .55285 L
s
.02381 .57625 m
.02756 .57625 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .35651 m
.02846 .35651 L
.03279 .35651 L
.03793 .35651 L
.04262 .35651 L
.0522 .35651 L
.05746 .35651 L
.06244 .35651 L
.06754 .35651 L
.07295 .35651 L
.08265 .35651 L
.08804 .35651 L
.09308 .35651 L
.09862 .35651 L
.10458 .35651 L
.11468 .35651 L
.1204 .35651 L
.12571 .35651 L
.13544 .35651 L
.14087 .35651 L
.1458 .35651 L
.15068 .35651 L
.15583 .35651 L
.16505 .35651 L
.17018 .35651 L
.17498 .35651 L
.18019 .35651 L
.18587 .35651 L
.1913 .35652 L
.19632 .35652 L
.20103 .35652 L
.20622 .35652 L
.21522 .35652 L
.22015 .35653 L
.22478 .35653 L
.23461 .35654 L
.23955 .35654 L
.24496 .35655 L
.2496 .35656 L
.25455 .35657 L
.26347 .3566 L
.2688 .35663 L
.27371 .35665 L
.279 .35669 L
.28481 .35674 L
.2946 .35685 L
.29996 .35694 L
.30496 .35704 L
.30994 .35716 L
.31537 .35733 L
Mistroke
.32016 .35751 L
.32525 .35775 L
.3303 .35804 L
.33487 .35837 L
.34379 .35921 L
.34868 .35982 L
.35384 .36063 L
.36307 .36258 L
.36822 .36404 L
.37301 .36573 L
.37823 .36799 L
.38391 .37109 L
.38935 .37484 L
.39439 .37916 L
.3991 .38413 L
.4043 .39088 L
.41331 .40667 L
.41824 .41813 L
.42287 .43115 L
.43273 .46784 L
.44309 .52095 L
.44809 .55019 L
.4528 .57655 L
.45485 .58648 L
.45703 .59508 L
.45816 .59855 L
.45941 .60136 L
.46055 .60289 L
.46161 .60332 L
.46285 .60246 L
.46402 .60017 L
.46508 .5968 L
.46622 .59165 L
.46747 .58422 L
.4688 .57418 L
.47118 .55064 L
.47603 .48332 L
.48139 .39055 L
.49034 .24163 L
.49484 .18369 L
.49977 .13539 L
.50229 .11615 L
.50499 .09906 L
.50748 .086 L
.50984 .07573 L
.51217 .0673 L
.51469 .05972 L
.51909 .04957 L
.5216 .04517 L
.52436 .04122 L
Mistroke
.52704 .03809 L
.52993 .03536 L
.53263 .03328 L
.5351 .0317 L
.53994 .02929 L
.54471 .02758 L
.54979 .02624 L
.55459 .02532 L
.55894 .02467 L
.56407 .02409 L
.56961 .02362 L
.57485 .02328 L
.57967 .02304 L
.58437 .02285 L
.58941 .02269 L
.59851 .02249 L
.60406 .0224 L
.60932 .02233 L
.61401 .02228 L
.61917 .02224 L
.62884 .02218 L
.63413 .02216 L
.6391 .02214 L
.64797 .02212 L
.65295 .02211 L
.65752 .0221 L
.66227 .02209 L
.66734 .02209 L
.67646 .02208 L
.68205 .02208 L
.68731 .02208 L
.69201 .02207 L
.69717 .02207 L
.7069 .02207 L
.71222 .02207 L
.7172 .02207 L
.7261 .02207 L
.73109 .02207 L
.73565 .02207 L
.74044 .02207 L
.74554 .02207 L
.75469 .02207 L
.7603 .02207 L
.76558 .02207 L
.77028 .02207 L
.77544 .02207 L
.78523 .02207 L
.79058 .02207 L
.79557 .02207 L
.8045 .02207 L
Mistroke
.8095 .02207 L
.81406 .02207 L
.81889 .02207 L
.82401 .02207 L
.8332 .02207 L
.8383 .02207 L
.84308 .02207 L
.84829 .02207 L
.85398 .02207 L
.85935 .02207 L
.86435 .02207 L
.86952 .02207 L
.87421 .02207 L
.88318 .02207 L
.8881 .02207 L
.89274 .02207 L
.90249 .02207 L
.90741 .02207 L
.9128 .02207 L
.91741 .02207 L
.92235 .02207 L
.93127 .02207 L
.93655 .02207 L
.94144 .02207 L
.9467 .02207 L
.9525 .02207 L
.96226 .02207 L
.9676 .02207 L
.97262 .02207 L
.97619 .02207 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00C03oool01@000000oooo0?ooo`3oool0000000<0oooo1P0000020?oo
o`030000003oool0oooo02L0oooo1@0000000`3oool000000?ooo`020?ooo`H000000P3oool00`00
0000oooo0?ooo`0Q0?ooo`D000000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000000`3oool600000080oooo00<000000?ooo`3oool0903oool300000080oooo00@00000
0?ooo`3oool0oooo1P0000020?ooo`030000003oool0oooo00d0oooo001;0?ooo`030000003oool0
000000<0oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
:P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo00L000000?ooo`3oool0
oooo0000003oool0000002@0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000030?oo
o`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000002D0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000
oooo0000000>0?ooo`00C@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo
00L000000?ooo`3oool0oooo0000003oool0000002X0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo0000000T0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`070000003o
ool0oooo0?ooo`000000oooo0000000V0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000003P3oool004/0oooo0P0000040?oo
o`030000003oool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000002X0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000
oooo0000000T0?ooo`030000003oool0oooo00H0oooo0P0000040?ooo`030000003oool0000000<0
oooo00L000000?ooo`3oool0oooo0000003oool0000002H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo0000000>0?ooo`00B`3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool01`000000oooo
0?ooo`3oool000000?ooo`000000:P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0000000T0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo00L000000?ooo`3oool0
oooo0000003oool0000002D0oooo00<000000?ooo`0000000P3oool01@000000oooo0?ooo`3oool0
00000080oooo00L000000?ooo`3oool0oooo0000003oool0000000h0oooo001;0?ooo`<00000203o
ool2000000@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0N0?ooo`8000002@3o
ool2000000@0oooo00<000000?ooo`3oool01P3oool3000001T0oooo0P0000080?ooo`<00000203o
ool2000000@0oooo00<000000?ooo`3oool01P3oool3000001`0oooo00<000000?ooo`3oool01`3o
ool2000000@0oooo00<000000?ooo`3oool01P3oool3000000@0oooo001V0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`000000?@3oool00`000000oooo0000000e0?ooo`030000003oool0
000000@0oooo001P0?ooo`<00000103oool00`000000oooo0?ooo`0b0?ooo`<000000P3oool30000
03P0oooo0`0000020?ooo`<00000<03oool300000080oooo0`0000040?ooo`00I`3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`040?ooo`007`3oool00`000000oooo0?ooo`130?ooo`<00000>P3oool2000003h0oooo
0P00000f0?ooo`800000103oool001l0oooo00<000000?ooo`3oool0oP3oool001l0oooo00<00000
0?ooo`3oool0oP3oool001T0ooooo000000;0?ooo`007`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool001l0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0140ooooI000000A0?ooo`007`3o
ool00`000000oooo0?ooo`210?ooo`P00000M@3oool001l0oooo00<000000?ooo`3oool0O`3oool2
000007d0oooo000O0?ooo`030000003oool0oooo07d0oooo0P00001o0?ooo`007`3oool2000007`0
oooo0P0000210?ooo`007`3oool00`000000oooo0?ooo`1k0?ooo`030000003oool0oooo0800oooo
000O0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0P@3oool001l0oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`220?ooo`007`3oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo0880oooo000O0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool0P`3oool001l0oooo0P00001i0?ooo`030000003oool0oooo08<0oooo000O0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool0P`3oool001l0oooo00<000000?ooo`3oool0N03oool0
0`000000oooo0?ooo`230?ooo`007`3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
08@0oooo000O0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0Q03oool001l0oooo
00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`250?ooo`007`3oool2000007L0oooo00<0
00000?ooo`3oool0Q@3oool001l0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`25
0?ooo`007`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo08D0oooo000O0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool0Q@3oool001l0oooo00<000000?ooo`3oool0
MP3oool00`000000oooo0?ooo`250?ooo`007`3oool00`000000oooo0?ooo`1f0?ooo`030000003o
ool0oooo08D0oooo000O0?ooo`800000MP3oool00`000000oooo0?ooo`260?ooo`007`3oool00`00
0000oooo0?ooo`1e0?ooo`030000003oool0oooo08H0oooo0005000000030?ooo`000000oooo0080
oooo1P0000020?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0M@3oool00`000000
oooo0?ooo`260?ooo`000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo
00L000000?ooo`3oool0oooo0000003oool0000000/0oooo00<000000?ooo`3oool0M@3oool00`00
0000oooo0?ooo`260?ooo`000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
oooo00L000000?ooo`3oool0oooo0000003oool0000000/0oooo00<000000?ooo`3oool0M@3oool0
0`000000oooo0?ooo`260?ooo`000P3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00<0oooo00L000000?ooo`3oool0oooo0000003oool0000000/0oooo00<000000?ooo`3oool0M@3o
ool00`000000oooo0?ooo`260?ooo`000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00@0
00000?ooo`3oool000000`3oool00`000000oooo0000000;0?ooo`<00000M@3oool00`000000oooo
0?ooo`260?ooo`0000<0oooo0000000000002@3oool2000000@0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo08H0oooo000F0?ooo`<000001P3oool0
0`000000oooo0?ooo`1e0?ooo`030000003oool0oooo08H0oooo000F0?ooo`030000003oool00000
00H0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`260?ooo`005P3oool3000000H0
oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`270?ooo`005P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0Q`3oool001L0oooo0P00
00060?ooo`800000M@3oool00`000000oooo0?ooo`270?ooo`007`3oool00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo08L0oooo000O0?ooo`030000003oool0oooo07@0oooo00<000000?oo
o`3oool0Q`3oool001l0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`270?ooo`00
7`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo08P0oooo000O0?ooo`800000M03o
ool00`000000oooo0?ooo`280?ooo`007`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0
oooo08P0oooo000O0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0R03oool001l0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`280?ooo`007`3oool00`000000oooo
0?ooo`1c0?ooo`030000003oool0oooo08P0oooo000O0?ooo`030000003oool0oooo07<0oooo00<0
00000?ooo`3oool0R03oool001l0oooo0P00001d0?ooo`030000003oool0oooo08P0oooo000O0?oo
o`030000003oool0oooo07<0oooo00<000000?ooo`3oool0R03oool001l0oooo00<000000?ooo`3o
ool0L`3oool00`000000oooo0?ooo`280?ooo`007`3oool00`000000oooo0?ooo`1b0?ooo`030000
003oool0oooo08T0oooo000O0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0R@3o
ool001l0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`290?ooo`007`3oool20000
07<0oooo00<000000?ooo`3oool0R@3oool001l0oooo00<000000?ooo`3oool0LP3oool00`000000
oooo0?ooo`290?ooo`007`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo08T0oooo
0000103oool000000000000000020?ooo`040000003oool0oooo0?ooo`H000000P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0R@3oool000030?oo
o`000000oooo00@0oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?oo
o`0000002`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo08T0oooo00020?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000002`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo08T0oooo00020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000002`3oool300000780oooo00<000000?ooo`3oool0R@3oool000040?ooo`000000
oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`070000003oool0oooo0?ooo`00
0000oooo0000000;0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0R@3oool00080
oooo00<000000?ooo`3oool01`3oool2000000@0oooo00@000000?ooo`3oool0oooo0`0000060?oo
o`030000003oool0oooo0780oooo00<000000?ooo`3oool0R@3oool001H0oooo00<000000?ooo`00
00001P3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo08T0oooo000F0?ooo`<00000
1P3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo08T0oooo000F0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`290?ooo`005`3oool2
000000H0oooo0P00001c0?ooo`030000003oool0oooo08T0oooo000O0?ooo`030000003oool0oooo
0780oooo00<000000?ooo`3oool0R@3oool001l0oooo00<000000?ooo`3oool0L@3oool00`000000
oooo0?ooo`2:0?ooo`007`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo08X0oooo
000O0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0RP3oool001l0oooo00<00000
0?ooo`3oool0L@3oool00`000000oooo0?ooo`2:0?ooo`007`3oool200000780oooo00<000000?oo
o`3oool0RP3oool001l0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`2:0?ooo`00
7`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo08X0oooo000O0?ooo`030000003o
ool0oooo0740oooo00<000000?ooo`3oool0RP3oool001l0oooo00<000000?ooo`3oool0L@3oool0
0`000000oooo0?ooo`2:0?ooo`007`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
08X0oooo000O0?ooo`800000LP3oool00`000000oooo0?ooo`2:0?ooo`007`3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo08X0oooo000O0?ooo`030000003oool0oooo0740oooo00<0
00000?ooo`3oool0RP3oool001l0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`2:
0?ooo`007`3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo08X0oooo000O0?ooo`03
0000003oool0oooo0740oooo00<000000?ooo`3oool0RP3oool001l0oooo0P00001b0?ooo`030000
003oool0oooo08X0oooo000O0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0RP3o
ool000030?ooo`000000000000<0oooo00@000000?ooo`3oool0oooo1P0000020?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`2:0?ooo`000`3oool0
1`000000oooo0?ooo`3oool000000?ooo`0000000`3oool01`000000oooo0?ooo`3oool000000?oo
o`0000002`3ooom>000002D0oooo00<000000?ooo`3oool0R`3oool00080oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`070000003oool0oooo0?ooo`000000oooo0000000;
0?ooo`030000003oool0oooo04/0oooo1P00000O0?ooo`030000003oool0oooo08/0oooo00030?oo
o`070000003oool0oooo0?ooo`000000oooo000000030?ooo`070000003oool0oooo0?ooo`000000
oooo0000000;0?ooo`<00000D@3oool5000001X0oooo00<000000?ooo`3oool0R`3oool000040?oo
o`000000oooo00000080oooo00D000000?ooo`3oool0oooo000000020?ooo`070000003oool0oooo
0?ooo`000000oooo0000000;0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`2;0?ooo`000P3oool00`000000oooo0?ooo`070?ooo`800000103oool0
10000000oooo0?ooo`3oool3000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo08/0oooo000F0?ooo`030000003oool0000000H0oooo00<00000
0?ooo`3oool0F03oool2000001H0oooo00<000000?ooo`3oool0R`3oool001H0oooo0`0000060?oo
o`030000003oool0oooo05X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`2;0?oo
o`005P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`2;0?ooo`005`3oool2000000H0oooo0P00001M0?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0R`3oool001l0oooo00<000000?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo08/0oooo000O0?ooo`030000003oool0
oooo05d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`2;0?ooo`007`3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0R`3oool001l0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo08/0
oooo000O0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`2;0?ooo`007`3oool200000600oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`2;0?ooo`007`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0R`3oool001l0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo08/0oooo000O0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`2;0?ooo`007`3oool00`000000oooo0?ooo`1Q0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0R`3oool001l0oooo00<000000?ooo`3oool0H@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08/0oooo000O0?ooo`800000HP3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo08/0oooo000O0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`2<0?ooo`007`3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0S03oool001l0oooo
00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo08`0oooo
000O0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`2<0?ooo`007`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0S03oool001l0oooo0P00001T0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0S03oool001l0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo08`0oooo00020?ooo`<0000000<0oooo0000003oool00P3oool600000080oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0S03oool000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000<0
oooo00L000000?ooo`3oool0oooo0000003oool0000000/0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo08`0oooo00000`3oool00000000000020000
00<0oooo00<000000?ooo`3oool00P3oool01`000000oooo0?ooo`3oool000000?ooo`0000002`3o
ool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0S03o
ool000040?ooo`000000oooo000000<0oooo00<000000?ooo`0000000`3oool01`000000oooo0?oo
o`3oool000000?ooo`0000002`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0S03oool00080oooo0P0000020?ooo`050000003oool0oooo0?ooo`00
00000P3oool01`000000oooo0?ooo`3oool000000?ooo`0000002`3oool3000006D0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`2<0?ooo`000`3oool00`000000oooo0?ooo`060?oo
o`800000103oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo06D0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`2<0?ooo`005P3oool3000000H0oooo00<000000?ooo`3o
ool0I@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08`0oooo000F0?ooo`030000
003oool0000000H0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo08`0oooo000F0?ooo`<000001P3oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0S03oool001H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S@3oool0
01L0oooo0P0000060?ooo`800000I`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
08d0oooo000O0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`2=0?ooo`007`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0S@3oool001l0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo08d0oooo000O0?ooo`030000003oool0oooo06H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`2=0?ooo`007`3oool2000006L0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`2=0?ooo`007`3oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S@3oool001l0oooo00<000000?ooo`3oool0
I`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08h0oooo000O0?ooo`030000003o
ool0oooo06L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2>0?ooo`007`3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0SP3oool0
01l0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
08h0oooo000O0?ooo`800000J@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo08h0
oooo000O0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`2>0?ooo`007`3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0SP3oool001l0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo08h0oooo000O0?ooo`030000003oool0oooo06T0oooo00D000000?oo
o`3oool0oooo0000002@0?ooo`007`3oool00`000000oooo0?ooo`1Y0?ooo`050000003oool0oooo
0?ooo`000000T03oool001l0oooo0P00001Z0?ooo`050000003oool0oooo0?ooo`000000T03oool0
01l0oooo00<000000?ooo`3oool0J@3oool010000000oooo0?ooo`00002A0?ooo`007`3oool00`00
0000oooo0?ooo`1Y0?ooo`040000003oool0oooo00000940oooo00020?ooo`050000003oool0oooo
0?ooo`0000000`3oool600000080oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1Y
0?ooo`040000003oool0oooo00000940oooo0000103oool000000?ooo`0000030?ooo`030000003o
ool0000000<0oooo00L000000?ooo`3oool0oooo0000003oool0000000/0oooo00<000000?ooo`3o
ool0J@3oool010000000oooo0?ooo`00002A0?ooo`000`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0080oooo00L000000?ooo`3oool0oooo0000003oool0000000/0oooo00<00000
0?ooo`3oool0JP3oool00`000000oooo0000002A0?ooo`0000<0oooo000000000000103oool00`00
0000oooo000000030?ooo`070000003oool0oooo0?ooo`000000oooo0000000;0?ooo`<00000JP3o
ool00`000000oooo0000002A0?ooo`0000<0oooo0000003oool00`3oool01@000000oooo0?ooo`3o
ool000000080oooo00L000000?ooo`3oool0oooo0000003oool0000000/0oooo00<000000?ooo`3o
ool0JP3oool200000980oooo0000103oool000000000000000080?ooo`800000103oool010000000
oooo0?ooo`3oool3000000H0oooo00<000000?ooo`3oool0oP3oool001H0oooo00<000000?ooo`00
00001P3oool00`000000oooo0?ooo`3n0?ooo`005P3oool3000000H0oooo00<000000?ooo`3oool0
oP3oool001H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3n0?ooo`005`3oool2
00000?l0oooo203oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0oooo8@3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.6489*^-07, -675105, 
  8.37302*^-09, 34082.3}}],

Cell[BoxData[
    \(\(-7419.07936401760803`\) + 1377.62022067463574`\ I\)], "Output"]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1440}, {0, 842}},
WindowSize->{496, 734},
WindowMargins->{{10, Automatic}, {Automatic, 15}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 2264, 37, 850, "Input"],
Cell[3998, 90, 40, 1, 25, "Print"],
Cell[4041, 93, 23496, 671, 186, 7571, 470, "GraphicsData", 
"PostScript", "Graphics"],
Cell[27540, 766, 40, 1, 25, "Print"],
Cell[27583, 769, 25886, 726, 186, 8054, 501, "GraphicsData", 
"PostScript", "Graphics"],
Cell[53472, 1497, 85, 1, 29, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

